@@ -8,6 +8,8 @@ from .version import version_tuple
 from tabulate import tabulate
 import textwrap
 
+# Configure for IPV4 only due to issue
+requests.packages.urllib3.util.connection.HAS_IPV6 = False
 
 # Define the API version
 api_version = f"{version_tuple[0]}.{version_tuple[1]}"
@@ -214,7 +216,15 @@ class TOOAPI_Baseclass:
         ):
             # Try to remember the password using keyring if available
             if keyring_support:
-                keyring.set_password("swifttools.swift_too", self.username, secret)
+                try:
+                    keyring.set_password("swifttools.swift_too", self.username, secret)
+                except keyring.errors.PasswordSetError:
+                    # This error is raised in if keyring support is enabled on
+                    # macOS, but the person isn't running the code interactively
+                    # or if they're logged in via ssh. Just trap and move on to
+                    # avoid code crashing.
+                    pass
+
         if self.username != "anonymous":
             self._shared_secret = secret
 
@@ -471,7 +481,7 @@ class TOOAPI_Baseclass:
             return True
         return False
 
-    def __submit_jwt(self, post=True):
+    def __submit_jwt(self, post=False):
         """Submit JWT request to the TOO API server, read in the reply and parse it."""
         # Don't submit an accepted or rejected request more than once
         if self.status == "Accepted":
